@@ -206,9 +206,9 @@ class dyn_obj:
 
         int_size = len(int_x)
         int_coords = np.zeros((int_size, 3))
-        int_coords[:, 0] = int_x
-        int_coords[:, 1] = int_y
-        int_coords[:, 2] = int_z
+        int_coords[:, 0] = int_x*self.scale
+        int_coords[:, 1] = int_y*self.scale
+        int_coords[:, 2] = int_z*self.scale
 
         int_curve = bpy.data.curves.new(name, type='CURVE')
         int_curve.dimensions = '3D'
